summaryrefslogtreecommitdiffstats
path: root/layout/style/nsCSSValue.h
diff options
context:
space:
mode:
Diffstat (limited to 'layout/style/nsCSSValue.h')
-rw-r--r--layout/style/nsCSSValue.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/layout/style/nsCSSValue.h b/layout/style/nsCSSValue.h
index bc8914bbc1..540ac91a49 100644
--- a/layout/style/nsCSSValue.h
+++ b/layout/style/nsCSSValue.h
@@ -55,14 +55,16 @@ enum nsCSSUnit : uint32_t {
// different behavior than percent)
// Font relative measure
- eCSSUnit_EM = 800, // == current font size
- eCSSUnit_XHeight = 801, // distance from top of lower case x to
- // baseline
- eCSSUnit_Char = 802, // number of characters, used for width with
- // monospace font
- eCSSUnit_RootEM = 803, // == root element font size
- eCSSUnit_Ideographic = 804, // == CJK water ideograph width
- eCSSUnit_CapHeight = 805, // == Capital letter height
+ eCSSUnit_EM = 800, // == current font size
+ eCSSUnit_XHeight = 801, // distance from top of lower case x to
+ // baseline
+ eCSSUnit_Char = 802, // number of characters, used for width with
+ // monospace font
+ eCSSUnit_RootEM = 803, // == root element font size
+ eCSSUnit_Ideographic = 804, // == CJK water ideograph width
+ eCSSUnit_CapHeight = 805, // == Capital letter height
+ eCSSUnit_LineHeight = 806, // == Line height
+ eCSSUnit_RootLineHeight = 807, // == Root line height
// Screen relative measure
eCSSUnit_Point = 900, // 4/3 of a CSS pixel